@@ -31,7 +31,10 @@ class Config(object):
         hps = utils.format_hyperparameters(hps)
         extend_hps, train_hps = utils.extract_hyperparameters(hps, constant.TI_PREFIX)
 
-        self.network_interface_name = extend_hps.get(constant.TI_NETWORK_INTERFACE_NAME, constant.DEFAULT_NIC_NAME)
+        if os.environ.get('OMPI_MCA_btl_tcp_if_include'):
+            self.network_interface_name = os.environ.get('OMPI_MCA_btl_tcp_if_include')
+        else:
+            self.network_interface_name = extend_hps.get(constant.TI_NETWORK_INTERFACE_NAME, constant.DEFAULT_NIC_NAME)
         self.log_level = extend_hps.get(constant.TI_CONTAINER_LOG_LEVEL, logging.INFO)
         self.user_entry_point = extend_hps.get(constant.TI_PROGRAM, '')
         self.parameter_server_enabled = extend_hps.get(constant.TI_PARAMETER_SERVER_ENABLED, '')
@@ -47,9 +50,13 @@ class Config(object):
 
         # parse resource config
         resource_config = utils.read_json_file(constant.RESOURCE_CONFIG_PATH)
-        self.current_host = resource_config[constant.CURRENT_HOST]
         self.hosts = resource_config[constant.HOSTS]
         self.mpi_operator_submit = resource_config.get(constant.MPI_OPERATOR_SUBMIT, False)
+        if self.mpi_operator_submit:
+            self.current_host = self.hosts[os.environ.get('INDEX')]
+        else:
+            self.current_host = resource_config[constant.CURRENT_HOST]
+
         self.is_master = self.current_host == self.hosts[0]
 
         if self.mpi_operator_submit:
